@@ -66,6 +66,7 @@ class Tokenizer(tokenization_abc.Tokenization):
 
         # add some stopwords to nlp list.
         self.nlp.stopwords_list(include=domain_stopwords)
+        self.nlp.__ngrams_replaced__ = True
 
         self.corpus_ngrams = None
 
@@ -74,7 +75,7 @@ class Tokenizer(tokenization_abc.Tokenization):
                       pos: Tuple[str, ...] = ("PROPN", "VERB", "NOUN", "ADJ"),
                       corpus_threshold: int = 50,
                       doc_threshold: int = 0,
-                      len_gram: int = 3, include: Tuple[str, ...] = None, replace: bool = True) -> List[Dict[int, str]]:
+                      len_gram: int = 3, include: Tuple[str, ...] = None, replace: bool = False) -> List[Dict[int, str]]:
         """
         Calculates frequent n-grams in the corpus. They will be considered as unique tokens during the Tokenization task. <br/>
         Frequent n-grams will be calculated based on the documents in the input stream (docs_in). <br/>
@@ -123,7 +124,7 @@ class Tokenizer(tokenization_abc.Tokenization):
                    ...
 
            include (Tuple[str, ...], optional, default=None): Include a list of arbitrary n-grams.
-           replace (bool, optional, default=True): If True, replaces a n-gram with its tokens separated by '_'. <br/> Else, concatenates a new token, made merging the n-gram tokens with '_', to the n-gram.
+           replace (bool, optional, default=False): If True, replaces a n-gram with its tokens separated by '_'. <br/> Else, concatenates a new token, made merging the n-gram tokens with '_', to the n-gram.
 
                    Example:
 
@@ -197,12 +198,15 @@ class Tokenizer(tokenization_abc.Tokenization):
         if docs_out is None:
             return
 
+        if replace:
+            self.nlp.__ngrams_replaced__ = replace
+
         for doc in docs_out:
             for ngram in self.corpus_ngrams:
                 if replace:
-                    doc[self.text_key] = doc[self.text_key].replace(ngram, ngram.replace(' ', '_'))
+                    doc[self.text_key] = doc[self.text_key].replace(ngram, "__"+ngram.replace(' ', '_')+"__")
                 else:
-                    doc[self.text_key] = doc[self.text_key].replace(ngram, ngram + ' ' + ngram.replace(' ', '_'))
+                    doc[self.text_key] = doc[self.text_key].replace(ngram, ngram + ' __' + ngram.replace(' ', '_')+"__")
             yield doc
 
     def run(self, docs: Iterable[Dict[str, str]], doc_id: int = 0, token_id: int = 0, sent_id: int = 0,
